require_relative 'treasure_trove'
require_relative 'playable'

module StudioGame
  class Player
    include Playable

    attr_reader :name
    attr_accessor :health
    
    def initialize(name, health=100)
      @health = health
      @name = name.capitalize
      @found_treasures = Hash.new(0)
    end

    def self.from_csv(string)
      name, health = string.split(',')
      Player.new(name, Integer(health))
    end

    def name=(new_name)
      @name = new_name.capitalize
    end

    def to_s
      "I'm #{@name} with a health = #{@health}, points = #{points} and a score = #{score}."
    end

    def score
      @health + points
    end

    def <=>(other)
      other.score <=> score
    end

    def found_treasure(treasure)
      @found_treasures[treasure.name] += treasure.points
      puts "#{@name} found a #{treasure.name} worth #{treasure.points} points."
    end

    def points
      @found_treasures.values.reduce(0, :+)
    end

    def each_found_treasure
      @found_treasures.each do |name, points|
        yield Treasure.new(name, points)
      end
    end
  end
end
